@@ -156,7 +156,7 @@ impl Face {
         (self.vertices[0] + self.vertices[1]) / 2.0
     }
 
-    /// Returns true if `other` is completely contained wihtin self
+    /// Returns true if `other` is completely contained within self
     pub fn contains(&self, other: &Self) -> bool {
         let dir = self.dir();
 
@@ -168,6 +168,14 @@ impl Face {
             || (b > -TOLERANCE && a > b && a * a < len + TOLERANCE)
     }
 
+    pub fn contains_point(&self, p: Vec2) -> bool {
+        let dir = self.dir();
+
+        let d = (p - self.vertices[0]).dot(dir);
+
+        d > -TOLERANCE && d < self.length() + TOLERANCE
+    }
+
     pub fn dir(&self) -> Vec2 {
         (self.vertices[1] - self.vertices[0]).normalize()
     }
@@ -254,10 +262,9 @@ pub enum Side {
 }
 
 impl Side {
-    pub fn min(&self, other: Self) -> Self {
+    pub fn min_side(&self, other: Self) -> Self {
         match (self, other) {
-            (Side::Back, _) => Side::Back,
-            (_, Side::Back) => Side::Back,
+            (Side::Back, _) | (_, Side::Back) => Side::Back,
             _ => *self,
         }
     }
