@@ -55,9 +55,6 @@ impl BSPTree {
             r = r.max(val);
         });
 
-        l -= Vec2::splat(10.0);
-        r += Vec2::splat(10.0);
-
         let mut nodes = SlotMap::with_key();
         let root = BSPNode::from_faces(&mut nodes, &faces, 0)?;
 
@@ -91,7 +88,7 @@ impl BSPTree {
             let rel = point - node.origin();
             let dot = rel.dot(node.normal());
 
-            let (next, covered) = if dot > 0.0 {
+            let (next, covered) = if dot >= 0.0 {
                 (node.front(), false)
             } else {
                 (node.back(), true)
@@ -144,6 +141,7 @@ impl BSPTree {
 }
 
 /// Represents the result of [crate::BSPTree::locate]
+#[derive(Clone, Debug)]
 pub struct NodePayload<'a> {
     pub index: NodeIndex,
     pub node: &'a BSPNode,
